-- ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-- Written by Kimberly L. Tripp - all rights reserved.
-- 
-- For more scripts and sample code, check out 
-- 	http://www.SQLSkills.com
--
-- Disclaimer - Thoroughly test this script, execute at your own risk.
-- ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

-- This sample script is really just the script that I used to build my larger and more interesting 
-- version of the Charge table. This script tries to modify using some creative math adding rowids
-- and membernos and datepart(ms, charge_dt) to reduce the patterns in the data.
-- The end result is a table with 5706577 rows. 

------------------------------------------------------------------------------------------------------------------------------------------------------------------------
------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-- IMPORTANT NOTE: This script should NOT be executed. It should only be used for learning!
------------------------------------------------------------------------------------------------------------------------------------------------------------------------
------------------------------------------------------------------------------------------------------------------------------------------------------------------------

USE Credit
go

SELECT min(Charge_dt), max(Charge_dt) FROM dbo.Charge
go

-- Create a new version of charges table with MORE data and increment the charge dates to cover 1 year July 1, 2003 to June 30, 2004
SELECT *
INTO ChargeFY04
FROM Charge

UPDATE ChargeFY04
	SET Charge_dt = dateadd(yy, 4, charge_dt)
go

UPDATE ChargeFY04
	SET Charge_dt = dateadd(yy, 1, charge_dt)
	WHERE Charge_dt < '20030701'
go

SELECT min(Charge_dt), max(Charge_dt) FROM dbo.ChargeFY04
go

ALTER TABLE ChargeFY04
	DROP COLUMN Charge_no

INSERT ChargeFY04 (member_no, provider_no, category_no, charge_dt, charge_amt, statement_no, charge_code)
	SELECT member_no, provider_no, category_no, dateadd(mm, 3, charge_dt), charge_amt, statement_no, charge_code 
	FROM ChargeFY04
	WHERE charge_dt < '20040401'
go

DELETE ChargeFY04
	WHERE charge_dt >= '20040701'
go -- none :-)

BACKUP LOG Credit WITH NO_LOG

ALTER TABLE ChargeFY04
	ADD ChargeFY04ID	INT		IDENTITY
go

BACKUP LOG Credit WITH NO_LOG
go

UPDATE ChargeFY04
	SET member_no = member_no + 3
	WHERE ChargeFY04ID % 31 = 0
go

UPDATE ChargeFY04
	SET member_no = member_no + 57
	WHERE ChargeFY04ID % 57 = 0
go

UPDATE ChargeFY04Staging
	SET charge_amt = charge_amt + 783
	WHERE ChargeFY04ID % 41 = 0
go

UPDATE ChargeFY04
	SET member_no = member_no % 10000
	WHERE member_no > 10000
go

DELETE ChargeFY04
	WHERE ChargeFY04ID % 67 = 0
go

sp_rename ChargeFY04, ChargeFY04Staging
go

CREATE TABLE ChargeFY04
( 	charge_no		numeric_id	NOT NULL IDENTITY,
	member_no	numeric_id NOT NULL
						CONSTRAINT ChargeFY04MemberNoFK
							REFERENCES dbo.Member(Member_No),
	provider_no	numeric_id
						CONSTRAINT ChargeFY04ProviderNoFK
							REFERENCES dbo.Provider(Provider_No),
	category_no	numeric_id
						CONSTRAINT ChargeFY04CategoryNoFK
							REFERENCES dbo.Category(Category_No),
	charge_dt		datetime,
	charge_amt	money,
	statement_no	numeric_id,
	charge_code	status_code
)
go
ALTER TABLE ChargeFY04Staging
	ADD ChargeFY04ID	INT		IDENTITY
go
UPDATE ChargeFY04Staging
	SET member_no = (member_no + ChargeFY04ID) % 10000
go
UPDATE ChargeFY04Staging
	SET charge_dt = 
				CASE 
					WHEN dateadd(ms, member_no, charge_dt) >= '20040701' 
						THEN dateadd(yy, -1, dateadd(ms, member_no, charge_dt))
					ELSE dateadd(ms, member_no, charge_dt)
				END
go

UPDATE ChargeFY04Staging
	SET charge_amt = charge_amt + datepart(ms, charge_dt)
go

UPDATE ChargeFY04Staging
	SET member_no = 
		CASE 
			WHEN provider_no + datepart(ms, charge_dt) > 10000 OR provider_no + datepart(ms, charge_dt) = 0
				THEN provider_no
			ELSE  provider_no + datepart(ms, charge_dt) 
		END
	WHERE member_no = 0
go

SELECT 
	SUM(CASE 
		WHEN Charge_dt >= '20030701' AND Charge_dt < '20031001' THEN 1
		ELSE 0
		END)
	AS 'FirstFY04Quarter',
	SUM(CASE 
		WHEN Charge_dt >= '20031001' AND Charge_dt < '20040101' THEN 1
		ELSE 0
		END)
	AS 'SecondFY04Quarter',
	SUM(CASE 
		WHEN Charge_dt >= '20040101' AND Charge_dt < '20040401' THEN 1
		ELSE 0
		END)
	AS 'ThirdFY04Quarter',
	SUM(CASE 
		WHEN Charge_dt >= '20040401' AND Charge_dt < '20040701' THEN 1
		ELSE 0
		END)
	AS 'ForthFY04Quarter'
FROM ChargeFY04Staging
go

ALTER TABLE ChargeFY04Staging
	DROP COLUMN ChargeFY04ID
go

INSERT ChargeFY04 (member_no, provider_no, category_no, charge_dt, charge_amt, statement_no, charge_code)
	SELECT * FROM ChargeFY04Staging ORDER BY charge_dt
go	

OK -- ChargeFY04 is entire table

SELECT count(*) FROM ChargeFY04

sp_renamedb Credit, CreditStagingCharges