-- ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-- Written by Kimberly L. Tripp - all rights reserved.
-- 
-- For more scripts and sample code, check out 
-- 	http://www.SQLSkills.com
--
-- Disclaimer - Thoroughly test this script, execute at your own risk.
-- ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

USE CreditPartitioned
go

ALTER DATABASE CreditPartitioned ADD FILEGROUP SingleTableSingleFilegroup
go

ALTER DATABASE CreditPartitioned 
	ADD FILE
		(NAME = N'CreditPartitionedSFGFile1', 
		FILENAME = N'C:\Program Files\Microsoft SQL Server\mssql\data\CreditPartitionedSFGFile1.NDF' , 
		SIZE = 300, FILEGROWTH = 10%) 
		TO FILEGROUP [SingleTableSingleFilegroup]
go

ALTER DATABASE CreditPartitioned 
	ADD FILE
		(NAME = N'CreditPartitionedSFGFile2', 
		FILENAME = N'C:\Program Files\Microsoft SQL Server\mssql\data\CreditPartitionedSFGFile2.NDF' , 
		SIZE = 300, FILEGROWTH = 10%) 
		TO FILEGROUP [SingleTableSingleFilegroup]
go

ALTER DATABASE CreditPartitioned 
	ADD FILE
		(NAME = N'CreditPartitionedSFGFile3', 
		FILENAME = N'C:\Program Files\Microsoft SQL Server\mssql\data\CreditPartitionedSFGFile3.NDF' , 
		SIZE = 300, FILEGROWTH = 10%) 
		TO FILEGROUP [SingleTableSingleFilegroup]
go

ALTER DATABASE CreditPartitioned 
	ADD FILE
		(NAME = N'CreditPartitionedSFGFile4', 
		FILENAME = N'C:\Program Files\Microsoft SQL Server\mssql\data\CreditPartitionedSFGFile4.NDF' , 
		SIZE = 300, FILEGROWTH = 10%) 
		TO FILEGROUP [SingleTableSingleFilegroup]
go

ALTER DATABASE CreditPartitioned ADD FILEGROUP FourTablesFilegroup1
go

ALTER DATABASE CreditPartitioned 
	ADD FILE
		(NAME = N'CreditPartitionedFFGFile1', 
		FILENAME = N'C:\Program Files\Microsoft SQL Server\mssql\data\CreditPartitionedFFGFile1.NDF' , 
		SIZE = 300, FILEGROWTH = 10%) 
		TO FILEGROUP [FourTablesFilegroup1]
go

ALTER DATABASE CreditPartitioned ADD FILEGROUP FourTablesFilegroup2
go

ALTER DATABASE CreditPartitioned 
	ADD FILE
		(NAME = N'CreditPartitionedFFGFile2', 
		FILENAME = N'C:\Program Files\Microsoft SQL Server\mssql\data\CreditPartitionedFFGFile2.NDF' , 
		SIZE = 400, FILEGROWTH = 10%) 
		TO FILEGROUP [FourTablesFilegroup2]
		-- Notice the larger size - must anticipate this when the data is NOT balanced...
go

ALTER DATABASE CreditPartitioned ADD FILEGROUP FourTablesFilegroup3
go

ALTER DATABASE CreditPartitioned 
	ADD FILE
		(NAME = N'CreditPartitionedFFGFile3', 
		FILENAME = N'C:\Program Files\Microsoft SQL Server\mssql\data\CreditPartitionedFFGFile3.NDF' , 
		SIZE = 300, FILEGROWTH = 10%) 
		TO FILEGROUP [FourTablesFilegroup3]
go

ALTER DATABASE CreditPartitioned ADD FILEGROUP FourTablesFilegroup4
go

ALTER DATABASE CreditPartitioned 
	ADD FILE
		(NAME = N'CreditPartitionedFFGFile4', 
		FILENAME = N'C:\Program Files\Microsoft SQL Server\mssql\data\CreditPartitionedFFGFile4.NDF' , 
		SIZE = 300, FILEGROWTH = 10%) 
		TO FILEGROUP [FourTablesFilegroup4]
go

-- Move a "staging" copy into it's own filegroup...
ALTER DATABASE CreditPartitioned ADD FILEGROUP ChargesFY04Staging
go

ALTER DATABASE CreditPartitioned 
	ADD FILE
		(NAME = N'ChargesFY04Staging', 
		FILENAME = N'C:\Program Files\Microsoft SQL Server\mssql\data\ChargesFY04Staging.NDF' , 
		SIZE = 500, FILEGROWTH = 10%) 
		TO FILEGROUP [ChargesFY04Staging]
go

-- Create the first table in the Staging Area and then rebuild the clustered index on the filegroup...
CREATE TABLE ChargeFY04
( 	charge_no		numeric_id		NOT NULL,
	member_no	numeric_id 	NOT NULL
						CONSTRAINT ChargeFY04MemberNoFK
							REFERENCES dbo.Member(Member_No),
	provider_no	numeric_id
						CONSTRAINT ChargeFY04ProviderNoFK
							REFERENCES dbo.Provider(Provider_No),
	category_no	numeric_id
						CONSTRAINT ChargeFY04CategoryNoFK
							REFERENCES dbo.Category(Category_No),
	charge_dt		datetime 	NOT NULL
						CONSTRAINT ChargeFY04ChargeDtCK
							CHECK (Charge_dt >= '20030701' AND Charge_dt < '20040701'),
	charge_amt	money		NOT NULL,
	statement_no	numeric_id,
	charge_code	status_code
) ON ChargesFY04Staging
go

INSERT ChargeFY04
	SELECT * FROM CreditStagingCharges.dbo.ChargeFY04
	ORDER BY Charge_dt, Charge_no
go

-- ALTER TABLE ChargeFY04
-- 	ALTER COLUMN Charge_no IDENTITY -- through the UI, not supported via syntax
-- ALTER TABLE ChargeFY04
--  	ALTER COLUMN Charge_dt NOT NULL -- through the UI, not supported via syntax
-- ALTER TABLE ChargeFY04
--  	ALTER COLUMN Charge_amt NOT NULL -- through the UI, not supported via syntax

-- CREATING A Single Table on a Single Filegroup and letting SQL Server do all the work - via the CL Index Rebuild....
-- Cluster on Charge_no make it the Primary Key

ALTER TABLE ChargeFY04
	ADD CONSTRAINT ChargeFY04PK
			PRIMARY KEY CLUSTERED (Charge_dt, Charge_no)
ON SingleTableSingleFilegroup
go

-- Now for the 4 tables on 4 filegroups...
-- First the staging tables...

CREATE TABLE ChargeFY04Q1
( 	charge_no		numeric_id		NOT NULL IDENTITY,
	member_no	numeric_id 	NOT NULL
						CONSTRAINT ChargeFY04Q1MemberNoFK
							REFERENCES dbo.Member(Member_No),
	provider_no	numeric_id
						CONSTRAINT ChargeFY04Q1ProviderNoFK
							REFERENCES dbo.Provider(Provider_No),
	category_no	numeric_id
						CONSTRAINT ChargeFY04Q1CategoryNoFK
							REFERENCES dbo.Category(Category_No),
	charge_dt		datetime 	NOT NULL
						CONSTRAINT ChargeFY04Q1ChargeDtCK
							CHECK (Charge_dt >= '20030701' AND Charge_dt < '20031001'),
	charge_amt	money		NOT NULL,
	statement_no	numeric_id,
	charge_code	status_code
) ON ChargesFY04Staging
go

CREATE TABLE ChargeFY04Q2
( 	charge_no		numeric_id		NOT NULL IDENTITY,
	member_no	numeric_id 	NOT NULL
						CONSTRAINT ChargeFY04Q2MemberNoFK
							REFERENCES dbo.Member(Member_No),
	provider_no	numeric_id
						CONSTRAINT ChargeFY04Q2ProviderNoFK
							REFERENCES dbo.Provider(Provider_No),
	category_no	numeric_id
						CONSTRAINT ChargeFY04Q2CategoryNoFK
							REFERENCES dbo.Category(Category_No),
	charge_dt		datetime 	NOT NULL
						CONSTRAINT ChargeFY04Q2ChargeDtCK
							CHECK (Charge_dt >= '20031001' AND Charge_dt < '20040101'),
	charge_amt	money		NOT NULL,
	statement_no	numeric_id,
	charge_code	status_code
) ON ChargesFY04Staging
go

CREATE TABLE ChargeFY04Q3
( 	charge_no		numeric_id		NOT NULL IDENTITY,
	member_no	numeric_id 	NOT NULL
						CONSTRAINT ChargeFY04Q3MemberNoFK
							REFERENCES dbo.Member(Member_No),
	provider_no	numeric_id
						CONSTRAINT ChargeFY04Q3ProviderNoFK
							REFERENCES dbo.Provider(Provider_No),
	category_no	numeric_id
						CONSTRAINT ChargeFY04Q3CategoryNoFK
							REFERENCES dbo.Category(Category_No),
	charge_dt		datetime 	NOT NULL
						CONSTRAINT ChargeFY04Q3ChargeDtCK
							CHECK (Charge_dt >= '20040101' AND Charge_dt < '20040401'),
	charge_amt	money		NOT NULL,
	statement_no	numeric_id,
	charge_code	status_code
) ON ChargesFY04Staging
go

CREATE TABLE ChargeFY04Q4
( 	charge_no		numeric_id		NOT NULL IDENTITY,
	member_no	numeric_id 	NOT NULL
						CONSTRAINT ChargeFY04Q4MemberNoFK
							REFERENCES dbo.Member(Member_No),
	provider_no	numeric_id
						CONSTRAINT ChargeFY04Q4ProviderNoFK
							REFERENCES dbo.Provider(Provider_No),
	category_no	numeric_id
						CONSTRAINT ChargeFY04Q4CategoryNoFK
							REFERENCES dbo.Category(Category_No),
	charge_dt		datetime 	NOT NULL
						CONSTRAINT ChargeFY04Q4ChargeDtCK
							CHECK (Charge_dt >= '20040401' AND Charge_dt < '20040701'),
	charge_amt	money		NOT NULL,
	statement_no	numeric_id,
	charge_code	status_code
) ON ChargesFY04Staging
go

SET IDENTITY_INSERT ChargeFY04Q1 ON
go
INSERT ChargeFY04Q1 (charge_no, member_no, provider_no, category_no, charge_dt, charge_amt, statement_no, charge_code)
	SELECT * 
	FROM CreditStagingCharges.dbo.ChargeFY04
	WHERE Charge_dt >= '20030701' AND Charge_dt < '20031001'
	ORDER BY Charge_dt, Charge_no
-- 1,205,310 row(s) affected
go
SET IDENTITY_INSERT ChargeFY04Q1 OFF
go


SET IDENTITY_INSERT ChargeFY04Q2 ON
go
INSERT ChargeFY04Q2 (charge_no, member_no, provider_no, category_no, charge_dt, charge_amt, statement_no, charge_code)
	SELECT * 
	FROM CreditStagingCharges.dbo.ChargeFY04
	WHERE Charge_dt >= '20031001' AND Charge_dt < '20040101'
	ORDER BY Charge_dt, Charge_no
-- 2,582,068 row(s) affected
go
SET IDENTITY_INSERT ChargeFY04Q2 OFF
go


SET IDENTITY_INSERT ChargeFY04Q3 ON
go
INSERT ChargeFY04Q3 (charge_no, member_no, provider_no, category_no, charge_dt, charge_amt, statement_no, charge_code)
	SELECT * 
	FROM CreditStagingCharges.dbo.ChargeFY04
	WHERE Charge_dt >= '20040101' AND Charge_dt < '20040401'
	ORDER BY Charge_dt, Charge_no
-- 1,548,422 row(s) affected
go
SET IDENTITY_INSERT ChargeFY04Q3 OFF
go


SET IDENTITY_INSERT ChargeFY04Q4 ON
go
INSERT ChargeFY04Q4 (charge_no, member_no, provider_no, category_no, charge_dt, charge_amt, statement_no, charge_code)
	SELECT * 
	FROM CreditStagingCharges.dbo.ChargeFY04
	WHERE Charge_dt >= '20040401' AND Charge_dt < '20040701'
	ORDER BY Charge_dt, Charge_no
-- 370,777 row(s) affected
go
SET IDENTITY_INSERT ChargeFY04Q4 OFF
go

ALTER TABLE ChargeFY04Q1
	ADD CONSTRAINT ChargeFY04Q1PK
			PRIMARY KEY CLUSTERED (Charge_dt, Charge_no)
ON FourTablesFilegroup1
go

ALTER TABLE ChargeFY04Q2
	ADD CONSTRAINT ChargeFY04Q2PK
			PRIMARY KEY CLUSTERED (Charge_dt, Charge_no)
ON FourTablesFilegroup2
go

ALTER TABLE ChargeFY04Q3
	ADD CONSTRAINT ChargeFY04Q3PK
			PRIMARY KEY CLUSTERED (Charge_dt, Charge_no)
ON FourTablesFilegroup3
go

ALTER TABLE ChargeFY04Q4
	ADD CONSTRAINT ChargeFY04Q4PK
			PRIMARY KEY CLUSTERED (Charge_dt, Charge_no)
ON FourTablesFilegroup4
go

CREATE VIEW dbo.ChargeFY04View
AS
SELECT * FROM dbo.ChargeFY04Q1
UNION
SELECT * FROM dbo.ChargeFY04Q2
UNION
SELECT * FROM dbo.ChargeFY04Q3
UNION
SELECT * FROM dbo.ChargeFY04Q4
go

SET STATISTICS IO ON
SELECT * FROM ChargeFY04
WHERE Charge_dt >= '20030914' AND Charge_dt < '20030915' 
-- 	(13122 row(s) affected)
-- 	Table 'ChargeFY04'. Scan count 1, logical reads 80, physical reads 0, read-ahead reads 13.

SELECT * FROM ChargeFY04View
WHERE Charge_dt >= '20030914' AND Charge_dt < '20030915' 
-- 	(13122 row(s) affected)
-- 	Table 'ChargeFY04Q4'. Scan count 0, logical reads 0, physical reads 0, read-ahead reads 0.
-- 	Table 'ChargeFY04Q3'. Scan count 0, logical reads 0, physical reads 0, read-ahead reads 0.
-- 	Table 'ChargeFY04Q2'. Scan count 0, logical reads 0, physical reads 0, read-ahead reads 0.
-- 	Table 'ChargeFY04Q1'. Scan count 1, logical reads 80, physical reads 0, read-ahead reads 0.

-- What about an index build...

SET STATISTICS IO ON
DECLARE @Start	datetime
SELECT @Start = getdate()
DBCC DBREINDEX ('ChargeFY04', 'ChargeFY04PK')
SELECT datediff(ms, @Start, getdate()) AS 'Total Time (ms)'
-- 534746 (8 minutes, 54 seconds)
-- Table 'ChargeFY04'. Scan count 1, logical reads 33178, physical reads 68, read-ahead reads 14386.

SELECT @Start = getdate()
DBCC DBREINDEX ('ChargeFY04Q4', 'ChargeFY04Q4PK')
SELECT datediff(ms, @Start, getdate()) AS 'Total Time (ms)'
-- 43583 (44 seconds)
-- Table 'ChargeFY04Q4'. Scan count 1, logical reads 2156, physical reads 0, read-ahead reads 2163.

-- Copy over another version of the data... Take first quarter FY04 and make it FY05 then export to file for loading...
-- Just to make sure...
-- SELECT max(charge_no) FROM ChargeFY04 -- 5706577
-- SELECT max(charge_no) FROM ChargeFY04View -- 5706577

-- Using DTS to export...
-- SELECT charge_no + 5706577 AS Charge_no, member_no, provider_no, category_no
--		, dateadd(yy, 1, charge_dt) AS Charge_dt, charge_amt, statement_no, charge_code
-- FROM ChargeFY04Q1
-- ORDER BY charge_dt, charge_no
go	

-- OK - importing... two versions... Need real indexes to really see BIG difference. Create indexes as needed for charge queries
-- 	NC Index on member_no, charge_amt
-- 	NC Index on provider_no, charge_amt
-- 	NC Index on category_no, charge_amt

CREATE INDEX ChargeFY04NC1 ON ChargeFY04(member_no, charge_amt)
-- 33266 I/O, 6:27 time
go
CREATE INDEX ChargeFY04NC2 ON ChargeFY04(provider_no, charge_amt)
-- 33266 I/O, 2:43 time
go
ALTER TABLE ChargeFY04 
	ADD CONSTRAINT ChargeFY04ChargeNoUK
		UNIQUE NONCLUSTERED (Charge_no)
-- Used a non-clustered to build this - less I/O, didn't need to table scan
-- 19166 I/O, 0:35 time


CREATE INDEX ChargeFY04Q1NC1 ON ChargeFY04Q1(member_no, charge_amt)
-- 7028 I/O
go
CREATE INDEX ChargeFY04Q1NC2 ON ChargeFY04Q1(provider_no, charge_amt)
-- 7028 I/O
go
ALTER TABLE ChargeFY04Q1 
	ADD CONSTRAINT ChargeFY04Q1ChargeNoUK
		UNIQUE NONCLUSTERED (Charge_no)
-- 4050 I/O
-- Time for ALL three 0:28 time
go


CREATE INDEX ChargeFY04Q2NC1 ON ChargeFY04Q2(member_no, charge_amt)
-- 15054 I/O
go
CREATE INDEX ChargeFY04Q2NC2 ON ChargeFY04Q2(provider_no, charge_amt)
-- 15054 I/O
go
ALTER TABLE ChargeFY04Q2
	ADD CONSTRAINT ChargeFY04Q2ChargeNoUK
		UNIQUE NONCLUSTERED (Charge_no)
-- 8673 I/O
-- Time for ALL three 3:25 time
go


CREATE INDEX ChargeFY04Q3NC1 ON ChargeFY04Q3(member_no, charge_amt)
-- 9028 I/O
go
CREATE INDEX ChargeFY04Q3NC2 ON ChargeFY04Q3(provider_no, charge_amt)
-- 9028 I/O
go
ALTER TABLE ChargeFY04Q3 
	ADD CONSTRAINT ChargeFY04Q3ChargeNoUK
		UNIQUE NONCLUSTERED (Charge_no)
-- 9202 I/O
-- Time for ALL three 0:49 time
go


CREATE INDEX ChargeFY04Q4NC1 ON ChargeFY04Q4(member_no, charge_amt)
-- 2163 I/O
go
CREATE INDEX ChargeFY04Q4NC2 ON ChargeFY04Q4(provider_no, charge_amt)
-- 2163 I/O
go
ALTER TABLE ChargeFY04Q4 
	ADD CONSTRAINT ChargeFY04Q4ChargeNoUK
		UNIQUE NONCLUSTERED (Charge_no)
-- 1248 I/O
-- Time for ALL three 0:07 time
go

-- All the indexes are in place...
-- For the "Single" table the process will consist of 
-- (1) Alter the table's check constraint to support new quarter (drop the old constraint)
-- (2) Load the data using BULK INSERT
-- (3) Delete the first quarter of F04
-- (4) Alter the table's check constraint to show new year range (drop the old constraint)

DECLARE @Start	datetime
SELECT @Start = getdate()
ALTER TABLE ChargeFY04
	ADD CONSTRAINT ChargeFY04ChargeDtCK2
			CHECK (Charge_dt >= '20030701' AND Charge_dt < '20041001')
SELECT datediff(ms, @Start, getdate()) AS 'Total Time (ms) - ADD CONSTRAINT'

SELECT @Start = getdate()
ALTER TABLE ChargeFY04
	DROP CONSTRAINT ChargeFY04ChargeDtCK
SELECT datediff(ms, @Start, getdate()) AS 'Total Time (ms) - DROP OLD CONSTRAINT'

-- has to scan entire table

SELECT @Start = getdate()
BULK INSERT CreditPartitioned.dbo.ChargeFY04 
	FROM 'C:\SYSolutions, Inc\ConferenceSessions\ChargesFY05Q1.csv' 
	WITH 
        ( 
            BATCHSIZE = 50000 
            , CHECK_CONSTRAINTS
		, DATAFILETYPE = 'char'
		, FIELDTERMINATOR = ','
		, ROWTERMINATOR = '\n' 
		, KEEPIDENTITY
--		, FIRSTROW = 10
--		, LASTROW = 10
		, ORDER ( charge_dt, charge_no )
        ) 
SELECT datediff(ms, @Start, getdate()) AS 'Total Time (ms) - BULK INSERT'

SELECT @Start = getdate()
DELETE ChargeFY04
	WHERE charge_dt < '20031001' 
SELECT datediff(ms, @Start, getdate()) AS 'Total Time (ms) - DELETE'

SELECT @Start = getdate()
ALTER TABLE ChargeFY04
	ADD CONSTRAINT ChargeFY04ChargeDtCK
			CHECK (Charge_dt >= '20031001' AND Charge_dt < '20041001')
SELECT datediff(ms, @Start, getdate()) AS 'Total Time (ms) - ADD New Range Constraint'

SELECT @Start = getdate()
ALTER TABLE ChargeFY04
	DROP CONSTRAINT ChargeFY04ChargeDtCK2
SELECT datediff(ms, @Start, getdate()) AS 'Total Time (ms) - DROP OLD Range Constraint'

-- For the Partitioned table the process will consist of 
--(1) Create New table - with constraints
--(2) Load the data using BULK INSERT
--(3) Change the view to use FY05Q1 and remove FY04Q1
--(4) Drop the table which represents FY04Q1 (could archived/backup)
--(5) Build Indexes - CL + 3 NC on FYQ1 Filegroup

DECLARE @Start	datetime
SELECT @Start = getdate()

CREATE TABLE ChargeFY05Q1
( 	charge_no	numeric_id		NOT NULL IDENTITY,
	member_no	numeric_id 	NOT NULL
						CONSTRAINT ChargeFY05Q1MemberNoFK
							REFERENCES dbo.Member(Member_No),
	provider_no	numeric_id
						CONSTRAINT ChargeFY05Q1ProviderNoFK
							REFERENCES dbo.Provider(Provider_No),
	category_no	numeric_id
						CONSTRAINT ChargeFY05Q1CategoryNoFK
							REFERENCES dbo.Category(Category_No),
	charge_dt		datetime 	NOT NULL
						CONSTRAINT ChargeFY05Q1ChargeDtCK
							CHECK (Charge_dt >= '20040701' AND Charge_dt < '20041001'),
	charge_amt	money		NOT NULL,
	statement_no	numeric_id,
	charge_code	status_code
) ON ChargesFY04Staging -- This is where the HEAP structure will live. The CL will be build appropriately
SELECT datediff(ms, @Start, getdate()) AS 'Total Time (ms) - Table Create'

SELECT @Start = getdate()
BULK INSERT CreditPartitioned.dbo.ChargeFY05Q1 
	FROM 'C:\SYSolutions, Inc\ConferenceSessions\ChargesFY05Q1.csv' 
	WITH 
        ( 
            BATCHSIZE = 50000 
            , CHECK_CONSTRAINTS
		, DATAFILETYPE = 'char'
		, FIELDTERMINATOR = ','
		, ROWTERMINATOR = '\n' 
		, KEEPIDENTITY
		, ORDER ( charge_dt, charge_no )
        ) 
SELECT datediff(ms, @Start, getdate()) AS 'Total Time (ms) - BULK INSERT'

SELECT getdate()
go
ALTER VIEW ChargeFY04View
AS
SELECT * FROM dbo.ChargeFY04Q2
UNION
SELECT * FROM dbo.ChargeFY04Q3
UNION
SELECT * FROM dbo.ChargeFY04Q4
go
SELECT getdate() AS 'Calculate alter view time - ALTER VIEW REMOVE PARTITION'

DECLARE @Start	datetime
SELECT @Start = getdate()
DROP TABLE dbo.ChargeFY04Q1
SELECT datediff(ms, @Start, getdate()) AS 'Total Time (ms) - DROP TABLE'

SELECT @Start = getdate()
ALTER TABLE ChargeFY05Q1
	ADD CONSTRAINT ChargeFY05Q1PK
		PRIMARY KEY CLUSTERED (charge_dt, charge_no)
	ON FourTablesFilegroup1
CREATE INDEX ChargeFY05Q1NC1 ON ChargeFY05Q1(member_no, charge_amt) ON FourTablesFilegroup1
CREATE INDEX ChargeFY05Q1NC2 ON ChargeFY05Q1(provider_no, charge_amt) ON FourTablesFilegroup1
ALTER TABLE ChargeFY05Q1 
	ADD CONSTRAINT ChargeFY05Q1ChargeNoUK
		UNIQUE NONCLUSTERED (Charge_no)
	ON FourTablesFilegroup1
SELECT datediff(ms, @Start, getdate()) AS 'Total Time (ms) - Index Creates'

SELECT getdate()
go
ALTER VIEW ChargeFY04View
AS
SELECT * FROM dbo.ChargeFY04Q2
UNION
SELECT * FROM dbo.ChargeFY04Q3
UNION
SELECT * FROM dbo.ChargeFY04Q4
UNION
SELECT * FROM dbo.ChargeFY05Q1
go
SELECT getdate() AS 'Calculate alter view time - ALTER VIEW ADD PARTITION'
go

------------------------------------------------------------------------------------------
-- DEMOS
------------------------------------------------------------------------------------------

SET STATISTICS IO ON
DECLARE @Start	datetime
SELECT @Start = getdate()
SELECT * FROM ChargeFY04
WHERE Charge_dt >= '20031114' AND Charge_dt < '20031115' 
SELECT datediff(ms, @Start, getdate()) AS 'Total Time (ms) - Query'
-- 	(13122 row(s) affected)
-- 	Table 'ChargeFY04'. Scan count 1, logical reads 80, physical reads 0, read-ahead reads 13.

SELECT @Start = getdate()
SELECT * FROM ChargeFY04View
WHERE Charge_dt >= '20031114' AND Charge_dt < '20031115' 
SELECT datediff(ms, @Start, getdate()) AS 'Total Time (ms) - Query'
go

sp_helpconstraint ChargeFY04
exec sp_helpconstraint ChargeFY04Q2
exec sp_helpconstraint ChargeFY04Q3
exec sp_helpconstraint ChargeFY04Q4
exec sp_helpconstraint ChargeFY05Q1

sp_helptext ChargeFY04View